@@ -73,8 +73,8 @@
  *     <title>Defining a ClutterAlpha in ClutterScript</title>
  *     <para>The following JSON fragment defines a #ClutterAlpha
  *     using a #ClutterTimeline with id "sine-timeline" and an alpha
- *     function called my_sine_alpha(). The defined #ClutterAlpha
- *     instance can be reused in multiple #ClutterBehaviour
+ *     function called <function>my_sine_alpha</function>. The defined
+ *     #ClutterAlpha instance can be reused in multiple #ClutterBehaviour
  *     definitions or for #ClutterAnimation definitions.</para>
  *     <programlisting><![CDATA[
  * {
@@ -303,7 +303,7 @@ clutter_alpha_parse_custom_node (ClutterScriptable *scriptable,
     {
       gulong mode;
 
-      mode = clutter_script_resolve_animation_mode (node);
+      mode = _clutter_script_resolve_animation_mode (node);
 
       g_value_init (value, G_TYPE_ULONG);
       g_value_set_ulong (value, mode);
