@@ -116,7 +116,6 @@
                                   CLUTTER_HYPER_MASK   | \
                                   CLUTTER_META_MASK)   | CLUTTER_RELEASE_MASK)
 
-typedef struct _ClutterBindingPoolClass ClutterBindingPoolClass;
 typedef struct _ClutterBindingEntry     ClutterBindingEntry;
 
 static GSList *clutter_binding_pools = NULL;
@@ -323,9 +322,9 @@ clutter_binding_pool_class_init (ClutterBindingPoolClass *klass)
                          CLUTTER_PARAM_READWRITE |
                          G_PARAM_CONSTRUCT_ONLY);
 
-  _clutter_object_class_install_properties (gobject_class,
-                                            PROP_LAST,
-                                            obj_props);
+  g_object_class_install_properties (gobject_class,
+                                     PROP_LAST,
+                                     obj_props);
 }
 
 static void
@@ -724,7 +723,7 @@ clutter_binding_pool_override_closure (ClutterBindingPool  *pool,
  *
  * Since: 1.0
  */
-G_CONST_RETURN gchar *
+const gchar *
 clutter_binding_pool_find_action (ClutterBindingPool  *pool,
                                   guint                key_val,
                                   ClutterModifierType  modifiers)
