@@ -167,7 +167,8 @@ static const GDebugKey clutter_debug_keys[] = {
   { "multistage", CLUTTER_DEBUG_MULTISTAGE },
   { "animation", CLUTTER_DEBUG_ANIMATION },
   { "layout", CLUTTER_DEBUG_LAYOUT },
-  { "clipping", CLUTTER_DEBUG_CLIPPING }
+  { "clipping", CLUTTER_DEBUG_CLIPPING },
+  { "oob-transforms", CLUTTER_DEBUG_OOB_TRANSFORMS }
 };
 #endif /* CLUTTER_ENABLE_DEBUG */
 
@@ -3029,11 +3030,11 @@ clutter_check_version (guint major,
  * clutter_get_default_text_direction:
  *
  * Retrieves the default direction for the text. The text direction is
- * determined by the locale and/or by the %CLUTTER_TEXT_DIRECTION environment
- * variable
+ * determined by the locale and/or by the <varname>CLUTTER_TEXT_DIRECTION</varname>
+ * environment variable.
  *
  * The default text direction can be overridden on a per-actor basis by using
- * clutter_actor_set_text_direction()
+ * clutter_actor_set_text_direction().
  *
  * Return value: the default text direction
  *
