@@ -114,7 +114,7 @@ void                  clutter_text_get_color            (ClutterText          *s
                                                          ClutterColor         *color);
 void                  clutter_text_set_font_name        (ClutterText          *self,
                                                          const gchar          *font_name);
-const gchar          *clutter_text_get_font_name        (ClutterText          *self);
+const gchar *         clutter_text_get_font_name        (ClutterText          *self);
 void                  clutter_text_set_font_description (ClutterText          *self,
                                                          PangoFontDescription *font_desc);
 PangoFontDescription *clutter_text_get_font_description (ClutterText          *self);
@@ -200,6 +200,11 @@ void                  clutter_text_set_single_line_mode (ClutterText          *s
                                                          gboolean              single_line);
 gboolean              clutter_text_get_single_line_mode (ClutterText          *self);
 
+void                  clutter_text_set_selected_text_color  (ClutterText          *self,
+                                                             const ClutterColor   *color);
+void                  clutter_text_get_selected_text_color  (ClutterText          *self,
+                                                             ClutterColor         *color);
+
 gboolean              clutter_text_activate             (ClutterText          *self);
 gboolean              clutter_text_position_to_coords   (ClutterText          *self,
                                                          gint                  position,
@@ -212,6 +217,10 @@ void                  clutter_text_set_preedit_string   (ClutterText          *s
                                                          PangoAttrList        *preedit_attrs,
                                                          guint                 cursor_pos);
 
+void                  clutter_text_get_layout_offsets   (ClutterText           *self,
+                                                         gint                  *x,
+                                                         gint                  *y);
+
 G_END_DECLS
 
 #endif /* __CLUTTER_TEXT_H__ */
