@@ -228,9 +228,9 @@ try_enable_drm (ClutterBackendWayland *backend_wayland, GError **error)
   glexts = glGetString(GL_EXTENSIONS);
   exts = eglQueryString (backend_wayland->edpy, EGL_EXTENSIONS);
 
-  if (!_cogl_check_extension ("EGL_KHR_image_base", exts) ||
-      !_cogl_check_extension ("EGL_MESA_drm_image", exts) ||
-      !_cogl_check_extension ("GL_OES_EGL_image", glexts))
+  if (!cogl_clutter_check_extension ("EGL_KHR_image_base", exts) ||
+      !cogl_clutter_check_extension ("EGL_MESA_drm_image", exts) ||
+      !cogl_clutter_check_extension ("GL_OES_EGL_image", glexts))
     {
       g_set_error (error, CLUTTER_INIT_ERROR,
 		   CLUTTER_INIT_ERROR_BACKEND,
@@ -336,12 +336,12 @@ clutter_backend_wayland_post_parse (ClutterBackend  *backend,
   return TRUE;
 }
 
-#if defined(HAVE_COGL_GL)
+#if defined(COGL_HAS_GL)
 #define _COGL_RENDERABLE_BIT EGL_OPENGL_BIT
-#elif defined(HAVE_COGL_GLES2)
+#elif defined(COGL_HAS_GLES2)
 #define _COGL_GLES_VERSION 2
 #define _COGL_RENDERABLE_BIT EGL_OPENGL_ES2_BIT
-#elif defined(HAVE_COGL_GLES)
+#elif defined(COGL_HAS_GLES1)
 #define _COGL_GLES_VERSION 1
 #define _COGL_RENDERABLE_BIT EGL_OPENGL_ES_BIT
 #endif
@@ -383,7 +383,7 @@ try_create_context (ClutterBackend  *backend,
 
   if (backend_wayland->egl_context == EGL_NO_CONTEXT)
     {
-#if defined(HAVE_COGL_GL)
+#if defined(COGL_HAS_GL)
       static const EGLint *attribs = NULL;
 #else
       static const EGLint attribs[] =
@@ -427,11 +427,11 @@ fail:
     }
 }
 
-#if defined(HAVE_COGL_GL)
+#if defined(COGL_HAS_GL)
 #define _COGL_SURFACELESS_EXTENSION "EGL_KHR_surfaceless_opengl"
-#elif defined(HAVE_COGL_GLES)
+#elif defined(COGL_HAS_GLES1)
 #define _COGL_SURFACELESS_EXTENSION "EGL_KHR_surfaceless_gles1"
-#elif defined(HAVE_COGL_GLES2)
+#elif defined(COGL_HAS_GLES2)
 #define _COGL_SURFACELESS_EXTENSION "EGL_KHR_surfaceless_gles2"
 #endif
 
@@ -449,14 +449,14 @@ clutter_backend_wayland_create_context (ClutterBackend  *backend,
   if (backend_wayland->egl_context != EGL_NO_CONTEXT)
     return TRUE;
 
-#if defined(HAVE_COGL_GL)
+#if defined(COGL_HAS_GL)
   eglBindAPI (EGL_OPENGL_API);
 #else
   eglBindAPI (EGL_OPENGL_ES_API);
 #endif
   egl_extensions = eglQueryString (backend_wayland->edpy, EGL_EXTENSIONS);
 
-  if (!_cogl_check_extension (_COGL_SURFACELESS_EXTENSION, egl_extensions))
+  if (!cogl_clutter_check_extension (_COGL_SURFACELESS_EXTENSION, egl_extensions))
     {
       g_debug("Could not find the " _COGL_SURFACELESS_EXTENSION
               " extension; falling back to binding a dummy surface");
